@@ -18,6 +18,53 @@ import warnings
 from tencentcloud.common.abstract_model import AbstractModel
 
 
+class AddClusterStorageOptionRequest(AbstractModel):
+    """AddClusterStorageOption请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ClusterId: 集群ID。
+        :type ClusterId: str
+        :param StorageOption: 集群存储选项。
+        :type StorageOption: :class:`tencentcloud.thpc.v20220401.models.StorageOption`
+        """
+        self.ClusterId = None
+        self.StorageOption = None
+
+
+    def _deserialize(self, params):
+        self.ClusterId = params.get("ClusterId")
+        if params.get("StorageOption") is not None:
+            self.StorageOption = StorageOption()
+            self.StorageOption._deserialize(params.get("StorageOption"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class AddClusterStorageOptionResponse(AbstractModel):
+    """AddClusterStorageOption返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class AddNodesRequest(AbstractModel):
     """AddNodes请求参数结构体
 
@@ -237,9 +284,9 @@ class CFSOption(AbstractModel):
 
     def __init__(self):
         r"""
-        :param LocalPath: 文件系统本地挂载路径
+        :param LocalPath: 文件系统本地挂载路径。
         :type LocalPath: str
-        :param RemotePath: 文件系统远程挂载ip及路径
+        :param RemotePath: 文件系统远程挂载ip及路径。
         :type RemotePath: str
         :param Protocol: 文件系统协议类型，默认值NFS 3.0。
 <li>NFS 3.0。
@@ -729,6 +776,51 @@ class DeleteClusterResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DeleteClusterStorageOptionRequest(AbstractModel):
+    """DeleteClusterStorageOption请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ClusterId: 集群ID。
+        :type ClusterId: str
+        :param LocalPath: 本地挂载路径。
+        :type LocalPath: str
+        """
+        self.ClusterId = None
+        self.LocalPath = None
+
+
+    def _deserialize(self, params):
+        self.ClusterId = params.get("ClusterId")
+        self.LocalPath = params.get("LocalPath")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DeleteClusterStorageOptionResponse(AbstractModel):
+    """DeleteClusterStorageOption返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DeleteNodesRequest(AbstractModel):
     """DeleteNodes请求参数结构体
 
@@ -836,6 +928,47 @@ class DescribeClusterActivitiesResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeClusterStorageOptionRequest(AbstractModel):
+    """DescribeClusterStorageOption请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ClusterId: 集群ID。
+        :type ClusterId: str
+        """
+        self.ClusterId = None
+
+
+    def _deserialize(self, params):
+        self.ClusterId = params.get("ClusterId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeClusterStorageOptionResponse(AbstractModel):
+    """DescribeClusterStorageOption返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeClustersRequest(AbstractModel):
     """DescribeClusters请求参数结构体
 
@@ -952,11 +1085,11 @@ class GooseFSOption(AbstractModel):
 
     def __init__(self):
         r"""
-        :param LocalPath: 文件系统本地挂载路径
+        :param LocalPath: 文件系统本地挂载路径。
         :type LocalPath: str
-        :param RemotePath: 文件系统远程挂载路径
+        :param RemotePath: 文件系统远程挂载路径。
         :type RemotePath: str
-        :param Masters: 文件系统master的ip和端口
+        :param Masters: 文件系统master的ip和端口。
         :type Masters: list of str
         """
         self.LocalPath = None
